
# Slot: required


Optional boolean key describing whether the attribute is required. Default value is True.

URI: [nwb_schema_language:required](https://w3id.org/p2p_ld/nwb-schema-language/required)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [Attribute](Attribute.md)
